import assert from 'assert';
import { multiaddr } from '@multiformats/multiaddr';
import { P2P_CIRCUIT_ID, P2P_WEBRTC_STAR_ID } from './constants.js';
export var ConnectionType;
(function (ConnectionType) {
    ConnectionType["Relayed"] = "relayed";
    ConnectionType["Direct"] = "direct";
})(ConnectionType || (ConnectionType = {}));
/**
 * Method to get self node info
 * @param node
 * @returns
 */
export const getPeerSelfInfo = (node) => {
    assert(node);
    return {
        peerId: node.peerId.toString(),
        multiaddrs: node.getMultiaddrs().map(multiaddr => multiaddr.toString())
    };
};
export const getPeerConnectionsInfo = (node) => {
    assert(node);
    const connectionsInfo = getConnectionsInfo(node);
    return connectionsInfo.map(connectionInfo => {
        const peerConnectionInfo = Object.assign(Object.assign({}, connectionInfo), { isPeerRelay: isRelayPeerMultiaddr(connectionInfo.multiaddr) });
        if (peerConnectionInfo.type === ConnectionType.Relayed) {
            const relayPeerId = multiaddr(peerConnectionInfo.multiaddr).decapsulate('p2p-circuit/p2p').getPeerId();
            if (relayPeerId !== null) {
                peerConnectionInfo.hopRelayPeerId = relayPeerId;
            }
        }
        return peerConnectionInfo;
    });
};
export const isPrimaryRelay = (multiaddrString, primaryRelayMultiaddr) => {
    return multiaddrString === primaryRelayMultiaddr.toString();
};
/**
 * Method to get connections info
 * @param node
 * @returns
 */
const getConnectionsInfo = (node) => {
    return node.getConnections().map(connection => {
        return {
            id: connection.id,
            peerId: connection.remotePeer.toString(),
            multiaddr: connection.remoteAddr.toString(),
            direction: connection.stat.direction,
            status: connection.stat.status,
            type: connection.remoteAddr.toString().includes('p2p-circuit/p2p') ? ConnectionType.Relayed : ConnectionType.Direct
        };
    });
};
const isRelayPeerMultiaddr = (multiaddrString) => {
    // Multiaddr not having p2p-circuit id or webrtc-star id is of a relay node
    return !(multiaddrString.includes(P2P_CIRCUIT_ID) || multiaddrString.includes(P2P_WEBRTC_STAR_ID));
};
//# sourceMappingURL=debug-info.js.map