import { getPseudonymForPeerId } from './peer-id-pseudonym.js';
import { ConnectionType } from './debug-info.js';
var GRAPH_NODE_COLOR;
(function (GRAPH_NODE_COLOR) {
    GRAPH_NODE_COLOR[GRAPH_NODE_COLOR["blue"] = 0] = "blue";
    GRAPH_NODE_COLOR[GRAPH_NODE_COLOR["green"] = 2] = "green";
    GRAPH_NODE_COLOR[GRAPH_NODE_COLOR["red"] = 3] = "red";
    GRAPH_NODE_COLOR[GRAPH_NODE_COLOR["yellow"] = 8] = "yellow";
})(GRAPH_NODE_COLOR || (GRAPH_NODE_COLOR = {}));
/**
 * Method to create/update graph data with debugInfo
 * @param selfPeerNode
 * @param primaryRelayMultiaddr
 * @param debugInfo
 * @param nodesMap
 * @param linksMap
 */
export const updateGraphDataWithDebugInfo = (selfPeerNode, debugInfo, options) => {
    const { nodesMap, linksMap, primaryRelayMultiaddr } = Object.assign({ nodesMap: new Map(), linksMap: new Map() }, options);
    const { selfInfo, connInfo } = debugInfo;
    // Update from selfInfo
    nodesMap.set(selfInfo.peerId, Object.assign(Object.assign(Object.assign({ 
        // Set node color to blue and label to Peer by default
        colorIndex: GRAPH_NODE_COLOR.blue, label: 'Peer' }, nodesMap.get(selfInfo.peerId)), { id: selfInfo.peerId, pseudonym: getPseudonymForPeerId(selfInfo.peerId), 
        // Override multiaddrs from selfInfo
        multiaddrs: selfInfo.multiaddrs }), (selfPeerNode.peerId.toString() === selfInfo.peerId) && { size: 14, colorIndex: GRAPH_NODE_COLOR.red, label: 'Self' }));
    // Update nodes from connections info
    connInfo.forEach((conn) => {
        const nodeData = Object.assign(Object.assign({ 
            // Set node color to blue and label to Peer by default
            colorIndex: GRAPH_NODE_COLOR.blue, label: 'Peer', 
            // Set connection multiaddr if node already does not exist
            // Self info will update with actual multiaddr
            multiaddrs: [conn.multiaddr] }, nodesMap.get(conn.peerId)), { id: conn.peerId, pseudonym: getPseudonymForPeerId(conn.peerId) });
        // Set relay node in the graph if primary relay passed
        if (primaryRelayMultiaddr) {
            if ('isPeerRelay' in conn && conn.isPeerRelay) {
                nodeData.colorIndex = GRAPH_NODE_COLOR.yellow;
                nodeData.label = 'Relay (secondary)';
                // Modify self peer's primary relay (if provided) in the graph
                if (conn.multiaddr === primaryRelayMultiaddr.toString()) {
                    nodeData.colorIndex = GRAPH_NODE_COLOR.green;
                    nodeData.label = 'Relay (primary)';
                }
            }
        }
        nodesMap.set(conn.peerId, nodeData);
    });
    // Update links from connections info
    connInfo.forEach((conn) => {
        let source = selfInfo.peerId;
        // Change source node for link to relay incase of relayed connection
        // Check if relay node exists in graph
        if (conn.type === ConnectionType.Relayed &&
            ('hopRelayPeerId' in conn) &&
            conn.hopRelayPeerId &&
            nodesMap.has(conn.hopRelayPeerId)) {
            source = conn.hopRelayPeerId;
        }
        // Form unique links between peers by concatenating ids based on comparison
        const linkId = source < conn.peerId ? `${source}-${conn.peerId}` : `${conn.peerId}-${source}`;
        linksMap.set(linkId, {
            id: linkId,
            source,
            target: conn.peerId
        });
    });
    return {
        nodesMap,
        linksMap
    };
};
//# sourceMappingURL=graph.js.map